import { Directive, ElementRef, Input, Renderer } from '@angular/core';
var identifier = 0;
var OverlayDirective = (function () {
    function OverlayDirective(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.overlayText = 'Loading';
        this._id = "overlay-item-" + identifier++;
    }
    OverlayDirective.prototype.ngOnInit = function () {
        var el = this.el.nativeElement;
        var div = this.renderer.createElement(el, 'div');
        this._updateInner = this.overlaySpinner ? this._updateSpinner : this._updateLabel;
        div.className = this._id;
        this.overlayText = this.overlayText || '';
    };
    OverlayDirective.prototype.ngOnChanges = function () {
        var el = this.el.nativeElement;
        var div = el.querySelector('.' + this._id);
        if (div) {
            if (this.overlay) {
                this._show(el, div);
            }
            else {
                this._reset(el, div);
            }
        }
    };
    OverlayDirective.prototype._show = function (el, div) {
        // update root element
        this._originStyle = el.getAttribute('style') || '';
        el.setAttribute('style', "position: relative;" + this._originStyle);
        this.renderer.setElementClass(el, 'overlay', true);
        // update overlay-item
        var styles = "position: absolute;\n        width:" + el.clientWidth + "px;\n        height:" + el.clientHeight + "px;\n        top: 0;\n        left: 0;\n        background: #ccc;\n        opacity: 0.7;\n        margin: 0;\n        text-align: center;";
        div.setAttribute('style', styles);
        this._updateInner(div, { height: el.clientHeight });
    };
    OverlayDirective.prototype._reset = function (el, div) {
        el.setAttribute('style', this._originStyle);
        div.setAttribute('style', '');
        div.innerHTML = '';
        this.renderer.setElementClass(el, 'overlay', false);
    };
    OverlayDirective.prototype._updateSpinner = function (div, options) {
        div.innerHTML = "<svg viewBox=\"0 0 100 100\" style=\"width:50px; margin-top:" + ((options.height / 2) - 25) + "px;\">\n  <circle id=\"hello1\" cx=\"50\" cy=\"50\" r=\"40\" stroke-dasharray=\"125\" stroke=\"black\" stroke-width=\"3\" fill=\"none\">\n     <animate attributeType=\"XML\" attributeName=\"stroke-dashoffset\" from=\"0\" to=\"-1000\" dur=\"4s\" repeatCount=\"indefinite\" fill=\"freeze\" />\n  </circle>\n</svg>";
    };
    OverlayDirective.prototype._updateLabel = function (div, options) {
        var label = this.renderer.createElement(div, 'label');
        label.setAttribute('style', "display: inline-block; margin-top: " + (options.height - 18) / 2 + "px;");
        label.innerText = this.overlayText;
    };
    OverlayDirective.decorators = [
        { type: Directive, args: [{ selector: '[overlay]' },] },
    ];
    /** @nocollapse */
    OverlayDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer, },
    ]; };
    OverlayDirective.propDecorators = {
        'overlay': [{ type: Input },],
        'overlayText': [{ type: Input },],
        'overlaySpinner': [{ type: Input },],
    };
    return OverlayDirective;
}());
export { OverlayDirective };
//# sourceMappingURL=overlay.directive.js.map